function calcDealerTrans(deck);
% Given the deck pdf, computes the start-finish transition
% matrix for the dealer's hand.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Blackjack Markov Chain Toolbox, v1.0 (08 Jan 2009)
%%% 
%%% Companion to manuscript 
%%%    "A Markov Chain Analysis of Blackjack Strategy"
%%%    by Michael B. Wakin and Christopher J. Rozell, 2004.
%%%    available at: http://inside.mines.edu/~mwakin/papers/mcbj.pdf
%%%
%%% Software Copyright 2009 by 
%%%    Michael B. Wakin, Colorado School of Mines, mwakin@mines.edu
%%%    Christopher J. Rozell, Georgia Tech, crozell@gatech.edu 
%%%
%%% This software is released under a Creative Commons license
%%% (Attribution 3.0 Unported): 
%%%     http://creativecommons.org/licenses/by/3.0/
%%% You are free:
%%%    * to Share  to copy, distribute and transmit the work
%%%    * to Remix  to adapt the work
%%% Under the following conditions:
%%%   * You must attribute the work by retaining this header information
%%%     crediting the original authors and linking to the original
%%%     manuscript.
%%%   * For any reuse or distribution, you must make clear to others the 
%%%     license terms of this work.
%%%   * Any of the above conditions can be waived if you get permission 
%%%     from the copyright holder.
%%%   * Nothing in this license impairs or restricts the author's 
%%%     moral rights.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global DEALERfirst DEALERhard DEALERsoft DEALERterm DEALERblackjack DEALERbust

global houseRules
global PD PDinf

PD(:,:) = 0;

% Set absorbing states
for ii = 17:21
  PD(DEALERterm(ii),DEALERterm(ii)) = 1;
end
PD(DEALERblackjack,DEALERblackjack) = 1;
PD(DEALERbust,DEALERbust) = 1;
PD(DEALERhard(17),DEALERterm(17)) = 1;

% Set first transitions
for ii = 2:11
  for dNew = 2:11
    newDtot = ii + dNew;
    newDsoft = ((ii == 11) | (dNew == 11));
    if (newDtot > 21)
      % Pair of aces
      newDtot = newDtot - 10;
      newDsoft = 1;
    end
    if (newDtot == 21)
      PD(DEALERfirst(ii),DEALERblackjack) = PD(DEALERfirst(ii),DEALERblackjack) + deck(dNew);
    elseif (newDtot > 17)
      PD(DEALERfirst(ii),DEALERterm(newDtot)) = PD(DEALERfirst(ii),DEALERterm(newDtot)) + deck(dNew);
    elseif (newDsoft)
      PD(DEALERfirst(ii),DEALERsoft(newDtot)) = PD(DEALERfirst(ii),DEALERsoft(newDtot)) + deck(dNew);
    else
      PD(DEALERfirst(ii),DEALERhard(newDtot)) = PD(DEALERfirst(ii),DEALERhard(newDtot)) + deck(dNew);
    end
  end
end

% Set hard transitions
for ii = 4:16
  for dNew = 2:11
    newDtot = ii + dNew;
    newDsoft = (dNew == 11);
    if ((newDtot > 21) & newDsoft)
      newDtot = newDtot - 10;
      newDsoft = 0;
    end
    if (newDtot > 21)
      PD(DEALERhard(ii),DEALERbust) = PD(DEALERhard(ii),DEALERbust) + deck(dNew);
    elseif (newDtot > 17)
      PD(DEALERhard(ii),DEALERterm(newDtot)) = PD(DEALERhard(ii),DEALERterm(newDtot)) + deck(dNew);
    elseif (newDsoft)
      PD(DEALERhard(ii),DEALERsoft(newDtot)) = PD(DEALERhard(ii),DEALERsoft(newDtot)) + deck(dNew);
    else
      PD(DEALERhard(ii),DEALERhard(newDtot)) = PD(DEALERhard(ii),DEALERhard(newDtot)) + deck(dNew);
    end
  end
end

% Set soft transitions (assume hit on soft 17, then correct if necessary)
for ii = 12:17
  for dNew = 2:11
    newDtot = ii + dNew;
    newDsoft = 1;
    if (newDtot > 21)
      newDtot = newDtot - 10;
      newDsoft = (dNew == 11);
    end
    if (newDtot > 17)
      PD(DEALERsoft(ii),DEALERterm(newDtot)) = PD(DEALERsoft(ii),DEALERterm(newDtot)) + deck(dNew);
    elseif (newDsoft)
      PD(DEALERsoft(ii),DEALERsoft(newDtot)) = PD(DEALERsoft(ii),DEALERsoft(newDtot)) + deck(dNew);
    else
      PD(DEALERsoft(ii),DEALERhard(newDtot)) = PD(DEALERsoft(ii),DEALERhard(newDtot)) + deck(dNew);
    end
  end
end
if (houseRules.DSSS)
  PD(DEALERsoft(17),:) = 0;
  PD(DEALERsoft(17),DEALERterm(17)) = 1;
end

PDinf = PD^18;

