function dProfit = computeTermProfit(pRow,pdRow);
% Computes expected profit, given player and dealer termination state 
% distributions. (Does not account for termination in split states.)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Blackjack Markov Chain Toolbox, v1.0 (08 Jan 2009)
%%% 
%%% Companion to manuscript 
%%%    "A Markov Chain Analysis of Blackjack Strategy"
%%%    by Michael B. Wakin and Christopher J. Rozell, 2004.
%%%    available at: http://inside.mines.edu/~mwakin/papers/mcbj.pdf
%%%
%%% Software Copyright 2009 by 
%%%    Michael B. Wakin, Colorado School of Mines, mwakin@mines.edu
%%%    Christopher J. Rozell, Georgia Tech, crozell@gatech.edu 
%%%
%%% This software is released under a Creative Commons license
%%% (Attribution 3.0 Unported): 
%%%     http://creativecommons.org/licenses/by/3.0/
%%% You are free:
%%%    * to Share  to copy, distribute and transmit the work
%%%    * to Remix  to adapt the work
%%% Under the following conditions:
%%%   * You must attribute the work by retaining this header information
%%%     crediting the original authors and linking to the original
%%%     manuscript.
%%%   * For any reuse or distribution, you must make clear to others the 
%%%     license terms of this work.
%%%   * Any of the above conditions can be waived if you get permission 
%%%     from the copyright holder.
%%%   * Nothing in this license impairs or restricts the author's 
%%%     moral rights.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global PLAYERterm PLAYERdoubTerm PLAYERtermSplit PLAYERblackjack PLAYERsurrender PLAYERbust PLAYERdoubBust

global DEALERterm DEALERblackjack DEALERbust

% pLow is probability that player finishes with 16 or less.  
pLow = sum(pRow(PLAYERterm(4:16)));

% pDoubLow is probability that player finishes with 16 or less (on double
% bet).
pDoubLow = sum(pRow(PLAYERdoubTerm(6:16)));

% Possible player outcomes: pLow,term17,...,term21,doubLow,
%  doubTerm17,...,doubTerm21,surrender,blackjack,bust,doubBust.

dProfit = 0;

%%% Case 1: Dealer blackjack
%   Player has blackjack
%dProfit = dProfit + 0;    
%   Player has no blackjack
dProfit = dProfit + (-1)*pdRow(DEALERblackjack)*(1-pRow(PLAYERblackjack));

%%% Case 2: Player blackjack (no dealer blackjack)
dProfit = dProfit + (1.5)*(1-pdRow(DEALERblackjack))*pRow(PLAYERblackjack);

%%% Case 3: Player surrenders (no dealer blackjack)
dProfit = dProfit + (-0.5)*(1-pdRow(DEALERblackjack))*pRow(PLAYERsurrender);

%%% Case 4: Player busts (no dealer blackjack)
dProfit = dProfit + (-1.0)*(1-pdRow(DEALERblackjack))*pRow(PLAYERbust);

%%% Case 5: Player busts (double bet) (no dealer blackjack)
dProfit = dProfit + (-2.0)*(1-pdRow(DEALERblackjack))*pRow(PLAYERdoubBust);

%%% No more need to account for dealer blackjacks, or player
%%%  blackjacks, surrenders, or busts...

%%% Case 6: Dealer busts
%   Player finishes <= 21
dProfit = dProfit + (1.0)*pdRow(DEALERbust)*(pLow+sum(pRow(PLAYERterm(17:21))));
%   Player finishes <= 21 (double bet)
dProfit = dProfit + (2.0)*pdRow(DEALERbust)*(pDoubLow+sum(pRow(PLAYERdoubTerm(17:21))));

%%% Case 7: Dealer finishes term(21)
%   Player finishes <= 20
dProfit = dProfit + (-1.0)*pdRow(DEALERterm(21))*(pLow+sum(pRow(PLAYERterm(17:20))));
%   Player finishes <= 20 (double bet)
dProfit = dProfit + (-2.0)*pdRow(DEALERterm(21))*(pDoubLow+sum(pRow(PLAYERdoubTerm(17:20))));
%   Player finishes 21 (single or double)
%dProfit = dProfit + 0;

%%% Case 8: Dealer finishes term(20)
%   Player finishes <= 19
dProfit = dProfit + (-1.0)*pdRow(DEALERterm(20))*(pLow+sum(pRow(PLAYERterm(17:19))));
%   Player finishes > 20, no bust
dProfit = dProfit + (1.0)*pdRow(DEALERterm(20))*pRow(PLAYERterm(21));
%   Player finishes <= 19 (double bet)
dProfit = dProfit + (-2.0)*pdRow(DEALERterm(20))*(pDoubLow+sum(pRow(PLAYERdoubTerm(17:19))));
%   Player finishes > 20, no bust (double bet)
dProfit = dProfit + (2.0)*pdRow(DEALERterm(20))*pRow(PLAYERdoubTerm(21));
%   Player finishes 20 (single or double)
%dProfit = dProfit + 0;

%%% Case 9: Dealer finishes term(19)
%   Player finishes <= 18
dProfit = dProfit + (-1.0)*pdRow(DEALERterm(19))*(pLow+pRow(PLAYERterm(17))+pRow(PLAYERterm(18)));
%   Player finishes > 19, no bust
dProfit = dProfit + (1.0)*pdRow(DEALERterm(19))*(pRow(PLAYERterm(20))+pRow(PLAYERterm(21)));
%   Player finishes <= 18 (double bet)
dProfit = dProfit + (-2.0)*pdRow(DEALERterm(19))*(pDoubLow+pRow(PLAYERdoubTerm(17))+pRow(PLAYERdoubTerm(18)));
%   Player finishes > 19, no bust (double bet)
dProfit = dProfit + (2.0)*pdRow(DEALERterm(19))*(pRow(PLAYERdoubTerm(20))+pRow(PLAYERdoubTerm(21)));
%   Player finishes 19 (single or double)
%dProfit = dProfit + 0;

%%% Case 10: Dealer finishes term(18)
%   Player finishes <= 17
dProfit = dProfit + (-1.0)*pdRow(DEALERterm(18))*(pLow+pRow(PLAYERterm(17)));
%   Player finishes > 18, no bust
dProfit = dProfit + (1.0)*pdRow(DEALERterm(18))*sum(pRow(PLAYERterm(19:21)));
%   Player finishes <= 17 (double bet)
dProfit = dProfit + (-2.0)*pdRow(DEALERterm(18))*(pDoubLow+pRow(PLAYERdoubTerm(17)));
%   Player finishes > 18, no bust (double bet)
dProfit = dProfit + (2.0)*pdRow(DEALERterm(18))*sum(pRow(PLAYERdoubTerm(19:21)));
%   Player finishes 18 (single or double)
%dProfit = dProfit + 0;

%%% Case 11: Dealer finishes term(17)
%   Player finishes <= 16
dProfit = dProfit + (-1.0)*pdRow(DEALERterm(17))*pLow;
%   Player finishes > 17, no bust
dProfit = dProfit + (1.0)*pdRow(DEALERterm(17))*sum(pRow(PLAYERterm(18:21)));
%   Player finishes <= 16 (double bet)
dProfit = dProfit + (-2.0)*pdRow(DEALERterm(17))*pDoubLow;
%   Player finishes > 17, no bust (double bet)
dProfit = dProfit + (2.0)*pdRow(DEALERterm(17))*sum(pRow(PLAYERdoubTerm(18:21)));
%   Player finishes 17 (single or double)
%dProfit = dProfit + 0;

